@@ -80,8 +80,8 @@ define ([
         priv = cf('currentUserPriv'),
         flag1;
 
-    // console.log("current-user: ce is ", ce);
-    // console.log("current-user: priv is " + priv);
+    console.log("current-user: ce is ", ce);
+    console.log("current-user: priv is " + priv);
 
     if (ce) {
         $.extend(cu, ce)
@@ -89,6 +89,7 @@ define ([
 
     // current-user function
     return function (sw, arg) { 
+        var emptyObj = { "nick": null };
         if (sw === 'obj') {
             // console.log('current-user function called with "obj"');
             if (arg) {
@@ -96,8 +97,15 @@ define ([
                 cu = arg;
                 cf('currentUser', cu);
             }
-            console.log('cu.nick is ' + cu.nick);
-            return cu.nick ? cu : null;
+            if (arg === null) {
+                console.log('NOTICE: resetting currentUser object');
+                cu = emptyObj;
+                cf('currentUser', cu);
+            }
+            // if ('nick' in cu && cu.nick) {
+            //     console.log('cu.nick is ' + cu.nick);
+            // }
+            return cu;
         }
         if (sw === 'priv') {
             // console.log('current-user function called with "priv"');
@@ -106,11 +114,16 @@ define ([
                 priv = arg;
                 cf('currentUserPriv', priv);
             }
+            if (arg === null || arg === "") {
+                console.log('NOTICE: resetting current user priv');
+                priv = null;
+                cf('currentUserPriv', priv);
+            }
             return priv;
         }
         if (sw === 'flag1') {
             // console.log('current-user function called with "flag1"');
-            if (arg || arg === 0) {
+            if (arg || arg === 0 || arg === 'null') {
                 console.log('NOTICE: setting current user flag1 to ' + arg);
                 flag1 = arg;
             }
