@@ -107,8 +107,8 @@ define ([
                 return;
             }
             if (typeof opts === "object") {
-                flag = opts.hasOwnProperty('flag') ? opts.flag : false;
-                xtarget = opts.hasOwnProperty('xtarget') ? opts.xtarget : null;
+                flag = ('flag' in opts) ? opts.flag : false;
+                xtarget = ('xtarget' in opts) ? opts.xtarget : null;
                 console.log("In stack.push(), setting flag", flag, "and xtarget", xtarget);
             }
             if (tgt.pushable) {
@@ -130,6 +130,10 @@ define ([
         getPush = function () {
             return _stack[_stack.length - 1].push;
         },
+        getStack = function () {
+            // returns the entire stack
+            return _stack;
+        },
         getState = function () {
             return _stack[_stack.length - 1].state;
         },
@@ -140,6 +144,10 @@ define ([
             return _stack[_stack.length - 1].xtarget;
         },
 
+        resetStack = function () {
+            // (re)initializes the stack to an empty array
+            _stack = [];
+        },
 
         setFlag = function () {
             _stack[_stack.length - 1].flag = true;
@@ -215,6 +223,7 @@ define ([
     return {
         "getFlag": getFlag,
         "getPush": getPush,
+        "getStack": getStack,
         "getState": getState,
         "getTarget": getTarget,
         "getXTarget": getXTarget,
@@ -222,6 +231,7 @@ define ([
         "pop": pop,
         "popWithoutStart": popWithoutStart,
         "push": push,
+        "resetStack": resetStack,
         "setFlag": setFlag,
         "setPush": setPush,
         "setState": setState,
