@@ -1,22 +1,22 @@
-// ************************************************************************* 
-// Copyright (c) 2014, SUSE LLC
-// 
+// *************************************************************************
+// Copyright (c) 2014-2017, SUSE LLC
+//
 // All rights reserved.
-// 
+//
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions are met:
-// 
+//
 // 1. Redistributions of source code must retain the above copyright notice,
 // this list of conditions and the following disclaimer.
-// 
+//
 // 2. Redistributions in binary form must reproduce the above copyright
 // notice, this list of conditions and the following disclaimer in the
 // documentation and/or other materials provided with the distribution.
-// 
+//
 // 3. Neither the name of SUSE LLC nor the names of its contributors may be
 // used to endorse or promote products derived from this software without
 // specific prior written permission.
-// 
+//
 // THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 // AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 // IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -28,7 +28,7 @@
 // CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 // POSSIBILITY OF SUCH DAMAGE.
-// ************************************************************************* 
+// *************************************************************************
 //
 // app/dform-init.js
 //
@@ -102,15 +102,8 @@ define ([
             'aclProfile': 'passerby',
             'entriesRead': [ entries.ROFormEntry1 ],
             'entriesWrite': [ entries.RWFormEntry1 ],
-            'hook': function () {
-                return {
-                    roentry1: 'Some information here',
-                    rwentry1: null
-                };
-            },
             'miniMenu': {
-                entries: ['demoActionFromForm'],
-                back: ['Back', 'demoSubmenu']
+                entries: ['demoActionFromForm']
             }
         });
 
@@ -123,10 +116,8 @@ define ([
             'aclProfile': 'passerby',
             'entriesRead': null,
             'entriesWrite': [entries.RWprop1, entries.RWprop2],
-            'hook': lib.holdObject,
             'miniMenu': {
-                entries: ['saveToBrowser'],
-                back: ['Back', 'returnToBrowser']
+                entries: ['saveToBrowser']
             }
         });
 
@@ -139,10 +130,8 @@ define ([
             'aclProfile': 'passerby',
             'entriesRead': null,
             'entriesWrite': [entries.RWprop1, entries.RWprop2],
-            'hook': lib.holdObject,
             'miniMenu': {
-                entries: ['saveToRowselect'],
-                back: ['Back', 'returnToRowselect']
+                entries: ['saveToRowselect']
             }
         });
 
